/*
 * Copyright 2012-2017 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.springframework.security.oauth2.client.user.converter;

import org.springframework.http.client.ClientHttpResponse;
import org.springframework.security.oauth2.oidc.user.DefaultUserInfo;
import org.springframework.security.oauth2.oidc.user.UserInfo;

import java.util.Map;

/**
 * An implementation of a {@link AbstractOAuth2UserConverter} that converts
 * a {@link ClientHttpResponse} to a {@link UserInfo}.
 *
 * @author Joe Grandja
 * @since 5.0
 * @see UserInfo
 * @see ClientHttpResponse
 */
public final class UserInfoConverter extends AbstractOAuth2UserConverter<UserInfo> {

	@Override
	protected UserInfo convert(Map<String, Object> userAttributes) {
		return new DefaultUserInfo(userAttributes);
	}
}
